function [PowerConsumption,mNoComprStages]=PowerConsumption(InstalledCapacity, unit,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure,mMolarMassA)

molPerKmol = 1000;
kgPerTon = 1000;
WPerkW = 1000;
EPerME = 1000000;
SecondPerHour = 3600;
mPermeateXa=Yp(1);
mFeedXa=Comp(1);
mGasConstant = 8.3144621;         % J/(K * mol)
mTstartCompression = 273 + 30;     % Temperature before feed compression [K]
mAmbientPressure = 1.013;          % Pressure before feed compression [bar]
% Const mMinPermeatePressure = 0.2
minPressureRatio = 1.05;
mMaxCompressorPR = 4;              %Max compressor pressure ratio [-]
mMixtureCp = 0.9802;               %Cp for CO2/N2 mixture of 0.3/0.7

unit1=1; 
unit2=2;

global mW_compglobal
global mW_expandglobal
global mW_suctnglobal
global mQ_ICglobal
global mLMTD

global mGammaConst1
global mGammaConst2

mGammaConst1=-0.1025;
mGammaConst2=1.4019;

mCostParam(1)=0.04;
mCostParam(2)=50;
mCostParam(3)=500;
mCostParam(4)=85;
mCostParam(5)=0;
mCostParam(6)=1.6;
mRotatingEquipmentEfficiency=0.8;
mNumberOfOperatingHours = 7446;
mProjectDuration = 25;
mNPVreferenceyear=1;
mDiscountRate = 8;
mDiscountFactor = 10.53;
mDirectFactor = 1;
mIndirectFactor = 1.375;
mConstructionPeriod = 3;
mOvernightFactor = 1;
mUnitaryCostOfMembraneModule = 39.5;
mMembraneFrameworkReferenceSize = 2000;
mMembraneFrameworkReferenceCost = 0;
mMembraneFrameworkReferenceCapacityScalePower = 0.7;
mMembraneFrameworkReferencePressureScalePower = 0.875;
mMembraneFrameworkReferencePressure = 55;
mCompressorFirstStageParameterA = 476.242600029007;
mCompressorSecondStageParameterA = 476.242600029007;
mCompressorThirdStageParameterA = 476.242600029007;
mExpanderParameterA = 355.134045882578;
mVacuumPumpParameterA = 952.485200058015;
mCoolerParameterA = 213.080427529547;
mOperatingAndMaintenancePercentageCost = 5;
mMembraneModuleLifetime = 5;
mMembraneReplacementFactor = 0.334713319497677;
mInitialCoolingWaterTemperature = 15 + 273;
mCoolingWaterTemperatureAfterCooling = 20 + 273;
mCoolingWaterHeatCapacity = 4.186;
mLMTD = 75.4550880191735;
mOverallHeatTransferCoefficient = 200;
mUnitaryCostOfElectricity = 0.105;
mUnitaryCostOfWaterCooling = 0.02;
% mFeedFlowRate = mFeedFlowVolume * 101.325 / mGasConstant / 273.15;
% Precondition: Molar mass, gamma parameters and compressor/expander efficiencies are defined.
% Postcondition: Returns power for compression and vacuum pumping.
%                 Updates values of mNoComprStages and global power variables to be used in investment cost calculations
%  Options:      Units:  0)W (default)
%                       1)J/kg_compA_permeate   (Carbon capture case)
%                        2)J/kg_tot_feed(IMPLEMENTATION TO BE CHECKED)
%                       3)J/kg_tot_retentate(IMPLEMENTATION TO BE CHECKED)    (N2/Natural gas case)
%                Optionally calculates the installed capacity (sum of contributions)
%
% Assumptions are compression from ambient and vacuum pumping with delivery to ambient.
% Ideal gas is used, so high pressure ratios should be used with caution.
%  ----------------------------- NB! -----------------------------------
%  Compression/pumping of permeate to delivery pressure is not included!
%  ---------------------------------------------------------------------
secondsPerHour = 3600;
molPerKmol = 1000;
[aPermeateFlow, aPermeateXb, aRetentateFlow, aRetnXa, aRetentateXb]=GetMassBalance(mFeedFlowRate,mStagecut,mPermeateXa,mFeedXa);

if mFeedPressure <= mAmbientPressure
    mNoComprStages=0;
else
    mNoComprStages=double(fix(log(mFeedPressure / mAmbientPressure) / log(mMaxCompressorPR))+1);
end

Cp = MixtureGamma(mFeedXa) / (MixtureGamma(mFeedXa) - 1) * mGasConstant;
if mNoComprStages > 0
    aPressureRatio = double((mFeedPressure / mAmbientPressure) ^ (1 / mNoComprStages));
    Tout = mTstartCompression * aPressureRatio ^ ((MixtureGamma(mFeedXa) - 1) / MixtureGamma(mFeedXa));  % Isentropic output temperature
    w_comp = Cp * (Tout - mTstartCompression) * 1 / mRotatingEquipmentEfficiency;
    Tout_act = Tout + (1 - mRotatingEquipmentEfficiency) * w_comp / Cp;                                  % Actual output temperature
    w_comp = w_comp * mNoComprStages; % total power is sum of all stages (since they are all equal)
else
    % No compressor
    aPressureRatio = 0;
    Tout = mTstartCompression;
    Tout_act = mTstartCompression;
    w_comp = 0;
end

% Expander
w_expand = MixtureGamma(aRetnXa) / (MixtureGamma(aRetnXa) - 1) * mGasConstant * mTstartCompression * (1 - (mAmbientPressure / mFeedPressure) ^ ((MixtureGamma(aRetnXa) - 1) / MixtureGamma(aRetnXa))) * mRotatingEquipmentEfficiency;

% Vacuum pump
w_suctn = MixtureGamma(mPermeateXa) / (MixtureGamma(mPermeateXa) - 1) * mGasConstant * mTstartCompression * ((mAmbientPressure / mPermeatePressure) ^ ((MixtureGamma(mPermeateXa) - 1) / MixtureGamma(mPermeateXa)) - 1) * 1 / mRotatingEquipmentEfficiency;

% Heat load for intercoolers, Joule per mol of feed flow
q_ideal = Cp * (Tout - mTstartCompression) * mNoComprStages;
q_irreversible = (1 - mRotatingEquipmentEfficiency) * w_comp;

% Write to global variables

mW_compglobal = w_comp * mFeedFlowRate / secondsPerHour * molPerKmol;                    %W
mW_expandglobal = w_expand * aRetentateFlow / secondsPerHour * molPerKmol;               %W
mW_suctnglobal = w_suctn * aPermeateFlow / secondsPerHour * molPerKmol;                  %W
mQ_ICglobal = (q_ideal + q_irreversible) * mFeedFlowRate / secondsPerHour * molPerKmol;  %W
mLMTD = ((Tout - mCoolingWaterTemperatureAfterCooling) - (mTstartCompression - mInitialCoolingWaterTemperature)) / log((Tout - mCoolingWaterTemperatureAfterCooling) / (mTstartCompression - mInitialCoolingWaterTemperature));
% Note: Excel WORKSHEET function Log has base 10, Excel VBA function Log has base e

switch unit
    case 1
        % Convert to W
        w_comp = w_comp * mFeedFlowRate / secondsPerHour * molPerKmol; % unit conversion from kmol/hr to mol/s
        w_expand = w_expand * aRetentateFlow / secondsPerHour * molPerKmol;
        w_suctn = w_suctn * aPermeateFlow / secondsPerHour * molPerKmol;
        
    case 2
        % Convert to Watt
        w_comp = w_comp * mFeedFlowRate / secondsPerHour * molPerKmol; % unit conversion from kmol/hr to mol/s
        w_expand = w_expand * aRetentateFlow / secondsPerHour * molPerKmol;
        w_suctn = w_suctn * aPermeateFlow / secondsPerHour * molPerKmol;
        % Convert to Watt/flow
        w_comp = w_comp / (aPermeateFlow * mPermeateXa * 1000 * mMolarMassA / 3600);
        w_expand = w_expand / (aPermeateFlow * mPermeateXa * 1000 * mMolarMassA / 3600);
        w_suctn = w_suctn / (aPermeateFlow * mPermeateXa * 1000 * mMolarMassA / 3600);
end
if InstalledCapacity==0 % Correct code when not is understood in matlab
    PowerConsumption = w_comp + w_suctn - w_expand;
else
    PowerConsumption = w_comp + w_suctn + w_expand;
end

function[PermeateFlow,PermeateXb,RetentateFlow,RetentateXa,RetentateXb]=GetMassBalance(mFeedFlowRate,mStagecut,mPermeateXa,mFeedXa)
PermeateFlow = mFeedFlowRate * mStagecut;
PermeateXb = 1 - mPermeateXa;
RetentateFlow = mFeedFlowRate * (1 - mStagecut);
RetentateXa = (mFeedXa - mStagecut * mPermeateXa) / (1 - mStagecut);
RetentateXb = 1 - RetentateXa;

function[MixtureGamma]=MixtureGamma(x_compA)
global mGammaConst1
global mGammaConst2
% Calculates adiabatic index using the linear regression parameters given as input
MixtureGamma = mGammaConst1 * x_compA + mGammaConst2;
% MixtureGamma = 1.35
