%% Cost calculation
function [SpecificArea,ConsumedPower,mCaptureCost]=calculatecost(Yp,mArea,mStagecut,CCR,mFeedFlowVolume,mFeedPressure,mPermeatePressure,mInletTemperature,Permeance,mMolarMassA,mMolarMassB,mMolarMassC,Comp)
% Calculates the specific capture cost for the current membrane in $/ton or /ton etc depending on the units
global mW_compglobal
global mW_expandglobal
global mW_suctnglobal
global mQ_ICglobal
global mLMTD
molPerKmol = 1000;
kgPerTon = 1000;
WPerkW = 1000;
EPerME = 1000000;
SecondPerHour = 3600;
mPermeateXa=Yp(1);
mFeedXa=Comp(1);
mGasConstant = 8.3144621;         % J/(K * mol)
mTstartCompression = 273 + 30;     % Temperature before feed compression [K]
mAmbientPressure = 1.013;          % Pressure before feed compression [bar]
% Const mMinPermeatePressure = 0.2
minPressureRatio = 1.05;
mMaxCompressorPR = 4;              %Max compressor pressure ratio [-]
mMixtureCp = 0.9802;               %Cp for CO2/N2 mixture of 0.3/0.7

unit1=1; 
unit2=2;

mGammaConst1=-0.1025;
mGammaConst2=1.4019;

mCostParam(1)=0.04;
mCostParam(2)=50;
mCostParam(3)=500;
mCostParam(4)=85;
mCostParam(5)=0;
mCostParam(6)=1.6;
mRotatingEquipmentEfficiency=0.8;
mNumberOfOperatingHours = 7446;
mProjectDuration = 25;
mNPVreferenceyear=1;
mDiscountRate = 8;
mDiscountFactor = 10.53;
mDirectFactor = 1;
mIndirectFactor = 1.375;
mConstructionPeriod = 3;
mOvernightFactor = 1;
mUnitaryCostOfMembraneModule = 39.5;
mMembraneFrameworkReferenceSize = 2000;
mMembraneFrameworkReferenceCost = 0;
mMembraneFrameworkReferenceCapacityScalePower = 0.7;
mMembraneFrameworkReferencePressureScalePower = 0.875;
mMembraneFrameworkReferencePressure = 55;
mCompressorFirstStageParameterA = 476.242600029007;
mCompressorSecondStageParameterA = 476.242600029007;
mCompressorThirdStageParameterA = 476.242600029007;
mExpanderParameterA = 355.134045882578;
mVacuumPumpParameterA = 952.485200058015;
mCoolerParameterA = 213.080427529547;
mOperatingAndMaintenancePercentageCost = 5;
mMembraneModuleLifetime = 5;
mMembraneReplacementFactor = 0.334713319497677;
mInitialCoolingWaterTemperature = 15 + 273;
mCoolingWaterTemperatureAfterCooling = 20 + 273;
mCoolingWaterHeatCapacity = 4.186;
mLMTD = 75.4550880191735;
mOverallHeatTransferCoefficient = 200;
mUnitaryCostOfElectricity = 0.105;
mUnitaryCostOfWaterCooling = 0.02;



mFeedFlowRate = mFeedFlowVolume * 101.325 / mGasConstant / 273.15;

[aPermeateFlow, aPermeateXb, aRetentateFlow, aRetentateXa, aRetentateXb]=GetMassBalance(mFeedFlowRate,mStagecut,mPermeateXa,mFeedXa);

% Get power consumption and update global variables for equipment powers
InstalledCapacity=0;
ElectricityPower = PowerConsumption(InstalledCapacity, unit1,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure) / WPerkW;

% Investment costs
% Membrane Investment costs
% Calculate the membrane module cost
MembraneModuleCost = mArea * mUnitaryCostOfMembraneModule * mIndirectFactor * mOvernightFactor / EPerME;

% Calculate the membrane framework cost
MembraneFrameworkCost = double(fix(mArea / 50000)+1) * double((mArea / (fix(mArea / 50000)+1)) / mMembraneFrameworkReferenceSize) ^ mMembraneFrameworkReferenceCapacityScalePower * mMembraneFrameworkReferenceCost * (mFeedPressure / mMembraneFrameworkReferencePressure) ^ mMembraneFrameworkReferencePressureScalePower * mIndirectFactor * mOvernightFactor / EPerME;

% Calculate the membrane overall investment cost
MembraneOverallInvestmentCost = MembraneModuleCost + MembraneFrameworkCost;

% Compressor Investment costs
% Calculation of the stages use
if mFeedPressure <= mAmbientPressure
    mNoComprStages=0;
else
    mNoComprStages=double(fix(log(mFeedPressure / mAmbientPressure) / log(mMaxCompressorPR))+1);
end
if mNoComprStages == 1
    NumberOfFirstStage = 1;
    NumberOfSecondStage = 0;
    NumberOfStagesAboveTwo = 0;
elseif mNoComprStages == 2
    NumberOfFirstStage = 1;
    NumberOfSecondStage = 1;
    NumberOfStagesAboveTwo = 0;
elseif mNoComprStages >= 3
    NumberOfFirstStage = 1;
    NumberOfSecondStage = 1;
    NumberOfStagesAboveTwo = mNoComprStages - 2;
else
    NumberOfFirstStage = 0;
    NumberOfSecondStage = 0;
    NumberOfStagesAboveTwo = 0;
end

% Calculation of the Compressor investment costs. Equal power in each stage.
if mNoComprStages > 0
    CompressorInvestmentcosts = (mW_compglobal / mNoComprStages / WPerkW) * (NumberOfFirstStage * mCompressorFirstStageParameterA + NumberOfSecondStage * mCompressorSecondStageParameterA + NumberOfStagesAboveTwo * mCompressorThirdStageParameterA) * mDirectFactor * mIndirectFactor * mOvernightFactor / EPerME;
else
    CompressorInvestmentcosts = 0;
end

% Expander Investment costs
ExpanderInvestmentcosts = (mW_expandglobal / WPerkW) * mExpanderParameterA * mDirectFactor * mIndirectFactor * mOvernightFactor / EPerME;

% Vacuum pump Investment costs
VacuumPumpInvestmentcosts = (mW_suctnglobal / WPerkW) * mVacuumPumpParameterA * mDirectFactor * mIndirectFactor * mOvernightFactor / EPerME;

% Coolers Investment costs
TotalCoolerArea = (mQ_ICglobal) / (mLMTD * mOverallHeatTransferCoefficient);    %KL
CoolerInvestmentcosts = TotalCoolerArea * mCoolerParameterA * mDirectFactor * mIndirectFactor * mOvernightFactor / EPerME;

% Calculation of the overall installed investment costs
OverallInstalledInvestmentCost = MembraneOverallInvestmentCost + CompressorInvestmentcosts + ExpanderInvestmentcosts + VacuumPumpInvestmentcosts + CoolerInvestmentcosts;


% Fixed Operating costs
% Calculate the annualized cost associated with the replacement of the membrane module
AnnualizedMembraneModuleReplacementCost = MembraneModuleCost * mMembraneReplacementFactor / mOvernightFactor / mDiscountFactor;

% Calculate the annual cost associated with operation and maintenance
AnnualOperatingAndInvestmentCosts = (OverallInstalledInvestmentCost / (mIndirectFactor * mOvernightFactor)) * (mOperatingAndMaintenancePercentageCost / 100);

% Calculate the overall Fixed Operating costs
OverallFixedOperatingCost = AnnualizedMembraneModuleReplacementCost + AnnualOperatingAndInvestmentCosts;


% Variable Operating costs
% Calculate the annual electricity cost
AnnualCostOfElectricity = PowerConsumption(InstalledCapacity, unit1,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure) / WPerkW * mNumberOfOperatingHours * mUnitaryCostOfElectricity / EPerME;

% Calculate the water cooling cost
CoolingWaterConsumption = (mQ_ICglobal / WPerkW) / (mCoolingWaterHeatCapacity * (mCoolingWaterTemperatureAfterCooling - mInitialCoolingWaterTemperature)) / kgPerTon * mNumberOfOperatingHours * SecondPerHour;
AnnualCostOfCoolingWater = CoolingWaterConsumption * mUnitaryCostOfWaterCooling / EPerME;

% Calculate the overall variable operating cost
OverallVariableOperatingCost = AnnualCostOfElectricity + AnnualCostOfCoolingWater;

% Calculate the Net Present value of Cost
NPVOfCost = OverallInstalledInvestmentCost + (OverallFixedOperatingCost + OverallVariableOperatingCost) * mDiscountFactor;

% Caluculate the unitary capture cost
denom = mPermeateXa * aPermeateFlow * molPerKmol * mMolarMassA * mNumberOfOperatingHours;
UnitaryCaptureCost = NPVOfCost * EPerME / ((denom) / kgPerTon * mDiscountFactor);

% Calculate total capital cost (turbomachinery installed capacity + membrane)
InstalledCapacity=1;
temp = PowerConsumption(InstalledCapacity, unit1,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure);
c = PowerConsumption(InstalledCapacity, unit1,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure) / WPerkW * mCostParam(2) + mArea * mCostParam(1) * mCostParam(5);
% Calculate cost of electricity per year
% aPlantCapacityFactor = mCostParam(3) / 100 * 365.15 * 24 % hr/year
InstalledCapacity=0;
% PTE = PowerConsumption(InstalledCapacity, unit1,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure) / WPerkW * aPlantCapacityFactor * mCostParam(0);

% denom = mPermeateXa * aPermeateFlow * molPerKmol * mMolarMassA * aPlantCapacityFactor
% Calculate specific capture cost

mCaptureCost = UnitaryCaptureCost;
SpecificArea = mArea / (mPermeateXa * aPermeateFlow * molPerKmol * mMolarMassA);
ConsumedPower=PowerConsumption(InstalledCapacity, unit2,Yp,Comp,mFeedFlowRate,mStagecut,mFeedPressure,mPermeatePressure,mMolarMassA) / 1000000;
%    mCaptureCost = (PTE + mCostParam(4) / 100 * c) / (denom) * kgPerTon
%    mCaptureCost = (PowerConsumption(False, 1) / 1000000 * 1000 / 3.6 * 365.15 * 24 * 0.85 * 0.04 + 0.2 * (500 * PowerConsumption(True, 1) / 3600 + 50 * 1.6 * SpecificArea * 1000)) / (365.15 * 24 * 0.85);

function[PermeateFlow,PermeateXb,RetentateFlow,RetentateXa,RetentateXb]=GetMassBalance(mFeedFlowRate,mStagecut,mPermeateXa,mFeedXa)
PermeateFlow = mFeedFlowRate * mStagecut;
PermeateXb = 1 - mPermeateXa;
RetentateFlow = mFeedFlowRate * (1 - mStagecut);
RetentateXa = (mFeedXa - mStagecut * mPermeateXa) / (1 - mStagecut);
RetentateXb = 1 - RetentateXa;

function[MixtureGamma]=MixtureGamma(x_compA)
% Calculates adiabatic index using the linear regression parameters given as input
MixtureGamma = mGammaConst1 * x_compA + mGammaConst2;
% MixtureGamma = 1.35
